@@ -246,10 +246,12 @@ class MultipleChoiceStringField(Field):
         assert default_value is None or (isinstance(default_value, str) and default_value in self.options)
 
 
+# noinspection DuplicatedCode
 class EnumStringField(Field):
     def __set__(self, instance, value, test: bool = False):
         if value is not None and value in self.enum_options:
-            value = value.value
+            if not isinstance(value, str):
+                value = value.value
         if value is not None and not isinstance(value, str):
             raise TypeError(instance, self.name, str, value)
         if value is not None and not (value in self.options):
@@ -317,7 +319,8 @@ class MultipleChoiceIntegerField(Field):
 class EnumIntegerField(Field):
     def __set__(self, instance, value, test: bool = False):
         if value is not None and value in self.enum_options:
-            value = value.value
+            if not isinstance(value, int):
+                value = value.value
         if value is not None and not isinstance(value, int):
             raise TypeError(instance, self.name, int, value)
         if value is not None and not (value in self.options):
@@ -349,6 +352,7 @@ class EnumIntegerField(Field):
         assert default_value is None or (isinstance(default_value, int) and default_value in self.options)
 
 
+# noinspection DuplicatedCode
 class DateField(Field):
     def get_json_formatted_value(self, value):
         if value is None:
@@ -542,6 +546,7 @@ class ListField(Field):
 
 
 class JsonObjectMeta(type):
+
     @staticmethod
     def __get_class_hierarchy_field_names(cls) -> List[str]:
         tmp_class_dict = cls.__dict__
@@ -552,6 +557,29 @@ class JsonObjectMeta(type):
                 model_field_names.extend(JsonObjectMeta.__get_class_hierarchy_field_names(base))
         return model_field_names
 
+    # noinspection DuplicatedCode
+    @staticmethod
+    def __get_fields(cls) -> List[Field]:
+        fields_list = []
+        type_dicts = cls.__dict__  # type(self).__dict__
+        for n, field in type_dicts.items():
+            if isinstance(field, Field):
+                fields_list.append(field)
+        for base in cls.__bases__:
+            base_type_dicts = base.__dict__  # type(self).__dict__
+            for n, field in base_type_dicts.items():
+                if isinstance(field, Field):
+                    fields_list.append(field)
+        return fields_list
+
+    @staticmethod
+    def __get_fields_mapped_by_names(cls) -> Dict[str, Field]:
+        result_dict = {}
+        fields_list = JsonObjectMeta.__get_fields(cls)
+        for field_item in fields_list:
+            result_dict[field_item.name] = field_item
+        return result_dict
+
     def __new__(mcs, name, bases, attrs: Dict[str, Any]):
         m_module = attrs.pop('__module__')
         new_attrs = {'__module__': m_module}
@@ -601,10 +629,16 @@ class JsonObjectMeta(type):
             _setattr(instance_self, 'serialized_name', None)
 
             model_field_names = JsonObjectMeta.__get_class_hierarchy_field_names(instance_self.__class__)
+            model_fields_by_name = JsonObjectMeta.__get_fields_mapped_by_names(instance_self.__class__)
+
+            # print(model_fields_by_name)
 
             for field_key in model_field_names:
                 if field_key not in init_kwargs.keys():
-                    _setattr(instance_self, field_key, None)
+                    if field_key in model_fields_by_name.keys():
+                        _setattr(instance_self, field_key, model_fields_by_name[field_key].default_value)
+                    else:
+                        _setattr(instance_self, field_key, None)
 
             # if extra_attributes is not None:
             #     print(extra_attributes)
@@ -774,7 +808,7 @@ class Pykson:
         return list_items
 
     @staticmethod
-    def __get_field_and_child_values_as_dict(json_object) -> Dict[str, Any]:
+    def __get_field_and_child_values_as_dict(json_object, serialized_keys_based: bool) -> Dict[str, Any]:
         fields_dict = {}
         type_dicts = type(json_object).__dict__
         for n, field in type_dicts.items():
@@ -782,12 +816,13 @@ class Pykson:
                 field_name = field.name
                 field_serialized_name = field.serialized_name
                 field_value = json_object.__getattribute__(field_name)
-                fields_dict[field_serialized_name] = field.get_json_formatted_value(field_value)
+                fields_dict[field_serialized_name if serialized_keys_based else field_name] = \
+                    field.get_json_formatted_value(field_value)
             elif isinstance(field, JsonObject):
                 field_name = n
                 field_serialized_name = n
                 field_value = json_object.__getattribute__(field_name)
-                fields_dict[field_serialized_name] = field_value
+                fields_dict[field_serialized_name if serialized_keys_based else field_name] = field_value
 
         bases_list: List[type] = Pykson.__get_json_object_bases(cls_type=type(json_object))
         # for base in type(json_object).__bases__:
@@ -929,14 +964,15 @@ class Pykson:
     #             final_dict[field_key] = field_value
     #     return final_dict
 
-    def _to_json(self, item: Union[T, List[T]]) -> Union[Dict[str, Any], List[Dict[str, Any]]]:
+    def _to_json(self, item: Union[T, List[T]], serialized_keys_based: bool = True) -> \
+            Union[Dict[str, Any], List[Dict[str, Any]]]:
         if isinstance(item, list):
             final_list = []
             for i in item:
                 final_list.append(self._to_json(i))
             return final_list
         else:
-            fields_dict = Pykson.__get_field_and_child_values_as_dict(item)
+            fields_dict = Pykson.__get_field_and_child_values_as_dict(item, serialized_keys_based)
             final_dict = {}
             # check if item type exists in type hierarchy adapters
             for type_hierarchy_adapter in self.type_hierarchy_adapters:
